pub struct DirectionalDelta {
pub from: String,
pub to: String,
pub delta_l: f32,
pub delta_a: f32,
pub delta_b: f32,
pub delta_e00: f32,
pub michelson_lightness_contrast: f32,
}Fields
from: Stringto: Stringdelta_l: f32delta_a: f32delta_b: f32delta_e00: f32michelson_lightness_contrast: f32Trait Implementations
Sourceimpl Clone for DirectionalDelta
impl Clone for DirectionalDelta
Sourcefn clone(&self) -> DirectionalDelta
fn clone(&self) -> DirectionalDelta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DirectionalDelta
impl Debug for DirectionalDelta
Sourceimpl<'de> Deserialize<'de> for DirectionalDelta
impl<'de> Deserialize<'de> for DirectionalDelta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DirectionalDelta
impl JsonSchema for DirectionalDelta
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DirectionalDelta
impl PartialEq for DirectionalDelta
Sourcefn eq(&self, other: &DirectionalDelta) -> bool
fn eq(&self, other: &DirectionalDelta) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DirectionalDelta
impl Serialize for DirectionalDelta
impl StructuralPartialEq for DirectionalDelta