pub struct MeasurementReport {
pub status: MeasurementStatus,
pub quality: CaptureQualityReport,
pub subject: Option<SubjectColorProfile>,
pub contrast_map: ContrastMap,
pub rankings: Vec<CandidateRanking>,
}Fields
status: MeasurementStatusquality: CaptureQualityReportsubject: Option<SubjectColorProfile>contrast_map: ContrastMaprankings: Vec<CandidateRanking>Trait Implementations
Sourceimpl Clone for MeasurementReport
impl Clone for MeasurementReport
Sourcefn clone(&self) -> MeasurementReport
fn clone(&self) -> MeasurementReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MeasurementReport
impl Debug for MeasurementReport
Sourceimpl<'de> Deserialize<'de> for MeasurementReport
impl<'de> Deserialize<'de> for MeasurementReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MeasurementReport
impl JsonSchema for MeasurementReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MeasurementReport
impl PartialEq for MeasurementReport
Sourcefn eq(&self, other: &MeasurementReport) -> bool
fn eq(&self, other: &MeasurementReport) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MeasurementReport
impl Serialize for MeasurementReport
impl StructuralPartialEq for MeasurementReport