pub struct ProviderMeta {
pub provider: ProviderKind,
pub model: String,
pub token_usage: TokenUsage,
}Fields
provider: ProviderKindmodel: Stringtoken_usage: TokenUsageTrait Implementations
Sourceimpl Clone for ProviderMeta
impl Clone for ProviderMeta
Sourcefn clone(&self) -> ProviderMeta
fn clone(&self) -> ProviderMeta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderMeta
impl Debug for ProviderMeta
Sourceimpl<'de> Deserialize<'de> for ProviderMeta
impl<'de> Deserialize<'de> for ProviderMeta
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProviderMeta
impl JsonSchema for ProviderMeta
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProviderMeta
impl PartialEq for ProviderMeta
Sourcefn eq(&self, other: &ProviderMeta) -> bool
fn eq(&self, other: &ProviderMeta) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProviderMeta
impl Serialize for ProviderMeta
impl StructuralPartialEq for ProviderMeta