pub struct ScoreComponents {
pub skin_quality: f32,
pub feature_readability: f32,
pub eye_support: f32,
pub lip_skin_harmony: f32,
pub hair_brow_coherence: f32,
pub goal_alignment: f32,
pub total_penalty: f32,
}Fields
skin_quality: f32feature_readability: f32eye_support: f32lip_skin_harmony: f32hair_brow_coherence: f32goal_alignment: f32total_penalty: f32Trait Implementations
Sourceimpl Clone for ScoreComponents
impl Clone for ScoreComponents
Sourcefn clone(&self) -> ScoreComponents
fn clone(&self) -> ScoreComponents
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScoreComponents
impl Debug for ScoreComponents
Sourceimpl<'de> Deserialize<'de> for ScoreComponents
impl<'de> Deserialize<'de> for ScoreComponents
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScoreComponents
impl JsonSchema for ScoreComponents
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ScoreComponents
impl PartialEq for ScoreComponents
Sourcefn eq(&self, other: &ScoreComponents) -> bool
fn eq(&self, other: &ScoreComponents) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ScoreComponents
impl Serialize for ScoreComponents
impl Copy for ScoreComponents
impl StructuralPartialEq for ScoreComponents