pub struct AgentBrief {
pub summary: String,
pub uncertainty: String,
}Fields
summary: Stringuncertainty: StringTrait Implementations
Sourceimpl Clone for AgentBrief
impl Clone for AgentBrief
Sourcefn clone(&self) -> AgentBrief
fn clone(&self) -> AgentBrief
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentBrief
impl Debug for AgentBrief
Sourceimpl<'de> Deserialize<'de> for AgentBrief
impl<'de> Deserialize<'de> for AgentBrief
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentBrief
impl JsonSchema for AgentBrief
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AgentBrief
impl PartialEq for AgentBrief
Sourcefn eq(&self, other: &AgentBrief) -> bool
fn eq(&self, other: &AgentBrief) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AgentBrief
impl Serialize for AgentBrief
impl StructuralPartialEq for AgentBrief