pub struct ContrastMap {
pub contrasts: Vec<DirectionalDelta>,
}Fields
contrasts: Vec<DirectionalDelta>Trait Implementations
Sourceimpl Clone for ContrastMap
impl Clone for ContrastMap
Sourcefn clone(&self) -> ContrastMap
fn clone(&self) -> ContrastMap
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContrastMap
impl Debug for ContrastMap
Sourceimpl<'de> Deserialize<'de> for ContrastMap
impl<'de> Deserialize<'de> for ContrastMap
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ContrastMap
impl JsonSchema for ContrastMap
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ContrastMap
impl PartialEq for ContrastMap
Sourcefn eq(&self, other: &ContrastMap) -> bool
fn eq(&self, other: &ContrastMap) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ContrastMap
impl Serialize for ContrastMap
impl StructuralPartialEq for ContrastMap